@@ -257,7 +257,7 @@ void TestBlogger1::errorPost(KBlog::Blog::ErrorType type, const QString &errStr,
         break;
     };
     qDebug() << "error: " << errStr;
-    if (post != 0) {
+    if (post != nullptr) {
         dumpPost(post);
     }
     qDebug() << "#############################\n";
