@@ -129,7 +129,7 @@ void WordpressBuggy::createPost(KBlog::BlogPost *post)
         xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->summary() + QStringLiteral("]]></string></value>");
         xmlMarkup += QStringLiteral("</member><member>");
         xmlMarkup += QStringLiteral("<name>mt_keywords</name>");
-        xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->tags().join(QStringLiteral(",")) + QStringLiteral("]]></string></value>");
+        xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->tags().join(QLatin1Char(',')) + QStringLiteral("]]></string></value>");
         xmlMarkup += QStringLiteral("</member></struct></param>");
         xmlMarkup += QStringLiteral("<param><value><boolean>") +
                      QStringLiteral("%1").arg((int)(!post->isPrivate())) +
@@ -141,12 +141,13 @@ void WordpressBuggy::createPost(KBlog::BlogPost *post)
         stream.writeRawData(xmlMarkup.toUtf8(), xmlMarkup.toUtf8().length());
 
         KIO::StoredTransferJob *job = KIO::storedHttpPost(postData, url(), KIO::HideProgressInfo);
+        if (!job) {
+            qCWarning(KBLOG_LOG) << "Failed to create job for: " << url().url();
+            return;
+        }
 
         d->mCreatePostMap[ job ] = post;
 
-        if (!job) {
-            qCWarning(KBLOG_LOG) << "Failed to create job for: " << url().url();
-        }
 
         job->addMetaData(
             QStringLiteral("customHTTPHeader"), QStringLiteral("X-hacker: Shame on you Wordpress, ") + QString() +
@@ -235,7 +236,7 @@ void WordpressBuggy::modifyPost(KBlog::BlogPost *post)
         xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->summary() + QStringLiteral("]]></string></value>");
         xmlMarkup += QStringLiteral("</member><member>");
         xmlMarkup += QStringLiteral("<name>mt_keywords</name>");
-        xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->tags().join(QStringLiteral(",")) + QStringLiteral("]]></string></value>");
+        xmlMarkup += QStringLiteral("<value><string><![CDATA[") + post->tags().join(QLatin1Char(',')) + QStringLiteral("]]></string></value>");
         xmlMarkup += QStringLiteral("</member></struct></param>");
         xmlMarkup += QStringLiteral("<param><value><boolean>") +
                      QStringLiteral("%1").arg((int)(!post->isPrivate())) +
@@ -247,12 +248,13 @@ void WordpressBuggy::modifyPost(KBlog::BlogPost *post)
         stream.writeRawData(xmlMarkup.toUtf8(), xmlMarkup.toUtf8().length());
 
         KIO::StoredTransferJob *job = KIO::storedHttpPost(postData, url(), KIO::HideProgressInfo);
+        if (!job) {
+            qCWarning(KBLOG_LOG) << "Failed to create job for: " << url().url();
+            return;
+        }
 
         d->mModifyPostMap[ job ] = post;
 
-        if (!job) {
-            qCWarning(KBLOG_LOG) << "Failed to create job for: " << url().url();
-        }
 
         job->addMetaData(
             QStringLiteral("customHTTPHeader"), QStringLiteral("X-hacker: Shame on you Wordpress, ") + QString() +
